SilentBindingService class
Constructors
Properties
- encryptionService → EncryptionService
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerSilentBinding(
{required String publicKey, required String? bindingId}) → Future< RegisterSilentBindingModel> -
toString(
) → String -
A string representation of this object.
inherited
-
verifySilentBinding(
{required String challenge, required String? bindingId}) → Future< VerifySilentBindingModel>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited